==> huaweicloudsdkrds-3.1.53-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/delete_backup_result.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteBackupResult:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'backup_id': 'str',
        'error_code': 'str',
        'error_msg': 'str'
    }

    attribute_map = {
        'backup_id': 'backup_id',
        'error_code': 'error_code',
        'error_msg': 'error_msg'
    }

    def __init__(self, backup_id=None, error_code=None, error_msg=None):
        """DeleteBackupResult

        The model defined in huaweicloud sdk

        :param backup_id: 备份id
        :type backup_id: str
        :param error_code: 提交任务异常时返回的错误编码。0表示成功。
        :type error_code: str
        :param error_msg: 提交任务异常时返回的错误描述信息。
        :type error_msg: str
        """
        
        

        self._backup_id = None
        self._error_code = None
        self._error_msg = None
        self.discriminator = None

        if backup_id is not None:
            self.backup_id = backup_id
        if error_code is not None:
            self.error_code = error_code
        if error_msg is not None:
            self.error_msg = error_msg

    @property
    def backup_id(self):
        """Gets the backup_id of this DeleteBackupResult.

        备份id

        :return: The backup_id of this DeleteBackupResult.
        :rtype: str
        """
        return self._backup_id

    @backup_id.setter
    def backup_id(self, backup_id):
        """Sets the backup_id of this DeleteBackupResult.

        备份id

        :param backup_id: The backup_id of this DeleteBackupResult.
        :type backup_id: str
        """
        self._backup_id = backup_id

    @property
    def error_code(self):
        """Gets the error_code of this DeleteBackupResult.

        提交任务异常时返回的错误编码。0表示成功。

        :return: The error_code of this DeleteBackupResult.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this DeleteBackupResult.

        提交任务异常时返回的错误编码。0表示成功。

        :param error_code: The error_code of this DeleteBackupResult.
        :type error_code: str
        """
        self._error_code = error_code

    @property
    def error_msg(self):
        """Gets the error_msg of this DeleteBackupResult.

        提交任务异常时返回的错误描述信息。

        :return: The error_msg of this DeleteBackupResult.
        :rtype: str
        """
        return self._error_msg

    @error_msg.setter
    def error_msg(self, error_msg):
        """Sets the error_msg of this DeleteBackupResult.

        提交任务异常时返回的错误描述信息。

        :param error_msg: The error_msg of this DeleteBackupResult.
        :type error_msg: str
        """
        self._error_msg = error_msg

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteBackupResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrds-3.1.157-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/delete_backup_result.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteBackupResult:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'backup_id': 'str',
        'error_code': 'str',
        'error_msg': 'str'
    }

    attribute_map = {
        'backup_id': 'backup_id',
        'error_code': 'error_code',
        'error_msg': 'error_msg'
    }

    def __init__(self, backup_id=None, error_code=None, error_msg=None):
        r"""DeleteBackupResult

        The model defined in huaweicloud sdk

        :param backup_id: 备份id
        :type backup_id: str
        :param error_code: 提交任务异常时返回的错误编码。0表示成功。
        :type error_code: str
        :param error_msg: 提交任务异常时返回的错误描述信息。
        :type error_msg: str
        """
        
        

        self._backup_id = None
        self._error_code = None
        self._error_msg = None
        self.discriminator = None

        if backup_id is not None:
            self.backup_id = backup_id
        if error_code is not None:
            self.error_code = error_code
        if error_msg is not None:
            self.error_msg = error_msg

    @property
    def backup_id(self):
        r"""Gets the backup_id of this DeleteBackupResult.

        备份id

        :return: The backup_id of this DeleteBackupResult.
        :rtype: str
        """
        return self._backup_id

    @backup_id.setter
    def backup_id(self, backup_id):
        r"""Sets the backup_id of this DeleteBackupResult.

        备份id

        :param backup_id: The backup_id of this DeleteBackupResult.
        :type backup_id: str
        """
        self._backup_id = backup_id

    @property
    def error_code(self):
        r"""Gets the error_code of this DeleteBackupResult.

        提交任务异常时返回的错误编码。0表示成功。

        :return: The error_code of this DeleteBackupResult.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        r"""Sets the error_code of this DeleteBackupResult.

        提交任务异常时返回的错误编码。0表示成功。

        :param error_code: The error_code of this DeleteBackupResult.
        :type error_code: str
        """
        self._error_code = error_code

    @property
    def error_msg(self):
        r"""Gets the error_msg of this DeleteBackupResult.

        提交任务异常时返回的错误描述信息。

        :return: The error_msg of this DeleteBackupResult.
        :rtype: str
        """
        return self._error_msg

    @error_msg.setter
    def error_msg(self, error_msg):
        r"""Sets the error_msg of this DeleteBackupResult.

        提交任务异常时返回的错误描述信息。

        :param error_msg: The error_msg of this DeleteBackupResult.
        :type error_msg: str
        """
        self._error_msg = error_msg

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteBackupResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
